==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/nl/admin/users/general.php <==
<?php


return array(
    'activated_help_text' => 'Deze gebruiker kan inloggen',
    'activated_disabled_help_text' => 'U kunt de activeringsstatus niet bewerken voor uw eigen account.',
    'assets_user'       => 'Assets toegewezen aan :name',
    'bulk_update_warn'	=> 'U staat op het punt om een aanpassing te maken aan de eigenschappen van :user_count gebruikers. Houd er rekening mee dat u niet uw eigen gebruikers eigenschappen kan aanpassen via dit formulier, u zal dit in uw eigen instellingen moeten doen.',
    'bulk_update_help'	=> 'Dit formulier maakt het mogelijk om meerdere gebruikers tegelijkertijd te bewerken, vul alleen de velden in die veranderd moeten worden. Blanco velden zullen ongewijzigd blijven.',
    'current_assets'    => 'Momenteel uitgecheckt aan deze gebruiker',
    'clone'             => 'Gebruiker dupliceren',
    'contact_user'      => 'Contact :name',
    'edit'              => 'Gebruiker aanpassen',
    'filetype_info'     => 'Toegestane bestandstypes zijn png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, and rar.',
    'history_user'      => 'Geschiedenis voor :name',
	'info'				=> 'Info',
    'restore_user'		=> 'Klik hier om ze te herstellen.',
    'last_login'        => 'Laatst aangemeld',
    'ldap_config_text'  => 'LDAP configuratie kan worden gevonden in Admin > Instellingen. De (optioneel) geselecteerde locatie zal voor alle geimporteerde gebruikers ingesteld worden.',
    'print_assigned'    => 'Print alles wat toegewezen is',
    'software_user'     => 'Software is uitgecheckt aan :name',
    'send_email_help'   => 'U moet een e-mailadres opgeven voor deze gebruiker om hen inloggegevens te sturen. E-mailen van inloggegevens kan alleen worden gedaan bij het maken van gebruikers. Wachtwoorden worden in eenrichtingshash opgeslagen en kunnen niet worden opgehaald zodra ze zijn opgeslagen.',
    'view_user'         => 'Bekijk gebruiker :name',
    'usercsv'           => 'CSV bestand',
    'two_factor_admin_optin_help' => 'De huidige beheer instellingen staan selectief gebruik van twee factor authenticatie toe.  ',
    'two_factor_enrolled' => 'Twee factor authenticatie apparaat ingesteld ',
    'two_factor_active'   => 'Twee factor authenticatie actief ',
    );

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/nl/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Deze gebruiker kan inloggen',
    'activated_disabled_help_text' => 'U kunt de activeringsstatus niet bewerken voor uw eigen account.',
    'assets_user'       => 'Assets toegewezen aan :name',
    'bulk_update_warn'	=> 'U staat op het punt om een aanpassing te maken aan de eigenschappen van :user_count gebruikers. Houd er rekening mee dat u niet uw eigen gebruikers eigenschappen kan aanpassen via dit formulier, u zal dit in uw eigen instellingen moeten doen.',
    'bulk_update_help'	=> 'Dit formulier maakt het mogelijk om meerdere gebruikers tegelijkertijd te bewerken, vul alleen de velden in die veranderd moeten worden. Blanco velden zullen ongewijzigd blijven.',
    'current_assets'    => 'Momenteel uitgecheckt aan deze gebruiker',
    'clone'             => 'Gebruiker dupliceren',
    'contact_user'      => 'Contact :name',
    'edit'              => 'Gebruiker aanpassen',
    'filetype_info'     => 'Toegestane bestandstypes zijn png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, and rar.',
    'history_user'      => 'Geschiedenis voor :name',
    'info'				=> 'Info',
    'restore_user'		=> 'Klik hier om ze te herstellen.',
    'last_login'        => 'Laatst aangemeld',
    'ldap_config_text'  => 'LDAP configuratie kan worden gevonden in Admin > Instellingen. De (optioneel) geselecteerde locatie zal voor alle geimporteerde gebruikers ingesteld worden.',
    'print_assigned'    => 'Print alles wat toegewezen is',
    'software_user'     => 'Software is uitgecheckt aan :name',
    'send_email_help'   => 'U moet een e-mailadres opgeven voor deze gebruiker om hen inloggegevens te sturen. E-mailen van inloggegevens kan alleen worden gedaan bij het maken van gebruikers. Wachtwoorden worden in eenrichtingshash opgeslagen en kunnen niet worden opgehaald zodra ze zijn opgeslagen.',
    'view_user'         => 'Bekijk gebruiker :name',
    'usercsv'           => 'CSV bestand',
    'two_factor_admin_optin_help' => 'De huidige beheer instellingen staan selectief gebruik van twee factor authenticatie toe.  ',
    'two_factor_enrolled' => 'Twee factor authenticatie apparaat ingesteld ',
    'two_factor_active'   => 'Twee factor authenticatie actief ',
    'user_deactivated'  => 'Gebruiker is ge-deactiveert',
    'activation_status_warning' => 'Activatiestatus niet wijzigen',
    'group_memberships_helpblock' => 'Alleen superadmins kunnen leden van groepen bewerken.',
    'superadmin_permission_warning' => 'Alleen superbeheerders mogen superadmin toegang verlenen aan een gebruiker.',
    'admin_permission_warning' => 'Alleen gebruikers met beheerdersrechten of hogere rechten mogen een gebruiker admin toegang verlenen.',
    'remove_group_memberships' => 'Groep lidmaatschappen verwijderen',
    'warning_deletion' => 'WAARSCHUWING:',
    'warning_deletion_information' => 'U staat op het punt om de :count gebruiker(s) hieronder te verwijderen. Superadmin namen worden rood gemarkeerd.',
    'update_user_asssets_status' => 'Alle assets voor deze gebruikers naar deze status updaten',
    'checkin_user_properties' => 'Check-in alle eigendommen gekoppeld aan deze gebruikers',
];
